@@ -15,17 +15,12 @@
 # limitations under the License.
 #
 
-import atexit
 import os
 import pyspark
-import re
-import shutil
 import sys
-import tempfile
 import warnings
 import zipfile
 from ai.h2o.sparkling.VersionComponents import VersionComponents
-from ai.h2o.sparkling.BackingJar import BackingJar
 from codecs import open
 from os import path
 from pyspark import SparkContext
@@ -45,42 +40,25 @@ class Initializer(object):
     __sparklingWaterJarLoaded = False
     __extracted_jar_dir = None
 
-    @staticmethod
-    def __setUpPySparkSubmitArgs():
-        # Ensure that when we do import pysparkling, spark will put later the JAR file
-        # to the driver. This option has effect only when SparkContext has not been started before.
-        if os.environ.get('PYSPARK_SUBMIT_ARGS') is None:
-            os.environ["PYSPARK_SUBMIT_ARGS"] = "--jars " + Initializer.__get_sw_jar(None) + " pyspark-shell"
-        else:
-            value = os.environ.get('PYSPARK_SUBMIT_ARGS')
-            if "--jars" not in value:
-                os.environ["PYSPARK_SUBMIT_ARGS"] = "--jars " + Initializer.__get_sw_jar(None) + " " + value
-            else:
-                pos = re.search("--jars\\s+", value).end()
-                os.environ["PYSPARK_SUBMIT_ARGS"] = value[:pos] + Initializer.__get_sw_jar(None) + "," + value[pos:]
-
     @staticmethod
     def load_sparkling_jar():
-        if Initializer.__sparklingWaterJarLoaded is False:
-            sc = SparkContext._active_spark_context
-            if sc is None:
-                Initializer.__setUpPySparkSubmitArgs()
+        sc = SparkContext._active_spark_context
+        if Initializer.__sparklingWaterJarLoaded is not True and sc is not None:
+            jvm = sc._jvm
+            stream = jvm.Thread.currentThread().getContextClassLoader().getResourceAsStream("sw.version")
+            if stream is None:
+                sys.path.append(".")
+                Initializer.__add_sparkling_jar_to_spark(sc)
             else:
-                jvm = sc._jvm
-                stream = jvm.Thread.currentThread().getContextClassLoader().getResourceAsStream("sw.version")
-                if stream is None:
-                    sys.path.append(".")
-                    Initializer.__add_sparkling_jar_to_spark(sc)
-                else:
-                    otherVersion = jvm.scala.io.Source.fromInputStream(stream, "UTF-8").mkString()
-                    currentVersion = Initializer.getVersion()
-                    if otherVersion != currentVersion:
-                        raise Exception("JAR file for Sparkling Water {} is already attached to the cluster, but you " \
-                                        "are starting PySparkling for {}. Either remove the attached JAR of the different " \
-                                        "version or use PySparkling of the same version as the attached JAR.".format(
-                            otherVersion,
-                            currentVersion))
-                Initializer.__sparklingWaterJarLoaded = True
+                otherVersion = jvm.scala.io.Source.fromInputStream(stream, "UTF-8").mkString()
+                currentVersion = Initializer.getVersion()
+                if otherVersion != currentVersion:
+                    raise Exception("JAR file for Sparkling Water {} is already attached to the cluster, but you " \
+                                    "are starting PySparkling for {}. Either remove the attached JAR of the different " \
+                                    "version or use PySparkling of the same version as the attached JAR.".format(
+                        otherVersion,
+                        currentVersion))
+            Initializer.__sparklingWaterJarLoaded = True
 
     @staticmethod
     def __add_sparkling_jar_to_spark(sc):
@@ -100,27 +78,21 @@ class Initializer(object):
         # when they need to use the dependency.
         sc._jsc.addJar(sw_jar_file)
 
-    @staticmethod
-    def __removeTmpDir():
-        shutil.rmtree(Initializer.__extracted_jar_dir)
-
     @staticmethod
     def __extracted_jar_path(sc):
 
         if Initializer.__extracted_jar_dir is None:
-            zip_file = Initializer.__get_pysparkling_package_path()
-            if sc is None:
-                Initializer.__extracted_jar_dir = tempfile.mkdtemp()
-                atexit.register(Initializer.__removeTmpDir)
-            else:
-                Initializer.__extracted_jar_dir = sc._temp_dir
+            zip_file = Initializer.__get_pysparkling_zip_path()
+            Initializer.__extracted_jar_dir = sc._temp_dir
+            import zipfile
             with zipfile.ZipFile(zip_file) as fzip:
-                fzip.extract(BackingJar.getRelativePath(), path=Initializer.__extracted_jar_dir)
+                fzip.extract('sparkling_water/sparkling_water_assembly.jar', path=Initializer.__extracted_jar_dir)
 
-        return os.path.abspath("{}/{}".format(Initializer.__extracted_jar_dir, BackingJar.getRelativePath()))
+        return os.path.abspath(
+            "{}/sparkling_water/sparkling_water_assembly.jar".format(Initializer.__extracted_jar_dir))
 
     @staticmethod
-    def __get_pysparkling_package_path():
+    def __get_pysparkling_zip_path():
         import sparkling_water
         sw_pkg_file = sparkling_water.__file__
         return sw_pkg_file[:-len('/sparkling_water/__init__.py')]
@@ -136,7 +108,7 @@ class Initializer(object):
         try:
             import h2o
             sw_h2o_version = h2o.__version__
-            zip_file_name = os.path.basename(Initializer.__get_pysparkling_package_path())
+            zip_file_name = os.path.basename(Initializer.__get_pysparkling_zip_path())
             path_without_sw = [i for i in sys.path if os.path.basename(i) != zip_file_name]
             command_sys_path = "import sys; sys.path = " + str(path_without_sw).replace("'", "\"") + ";"
             command_import_h2o = "import h2o; print(h2o.__version__)"
@@ -154,13 +126,14 @@ class Initializer(object):
 
     @staticmethod
     def __get_sw_jar(sc):
-        packagePath = Initializer.__get_pysparkling_package_path()
+        import sparkling_water
+        sw_pkg_file = sparkling_water.__file__
         # Extract jar file from zip
-        if zipfile.is_zipfile(packagePath):
+        if '.zip' in sw_pkg_file:
             return Initializer.__extracted_jar_path(sc)
         else:
             from pkg_resources import resource_filename
-            return os.path.abspath(resource_filename("sparkling_water", BackingJar.getName()))
+            return os.path.abspath(resource_filename("sparkling_water", 'sparkling_water_assembly.jar'))
 
     @staticmethod
     def __get_logger(jvm):
@@ -190,24 +163,14 @@ class Initializer(object):
                 logger.debug("Skipping classloader '{}'".format(loader.toString()))
             loader = loader.getParent()
 
-    @staticmethod
-    def isRunningViaDBCConnect():
-        import pkg_resources as pkg
-        try:
-            pkg.get_distribution('databricks-connect')
-            return True
-        except:
-            return False
-
     @staticmethod
     def getVersion():
-        packagePath = Initializer.__get_pysparkling_package_path()
-        versionFile = 'ai/h2o/sparkling/version.txt'
-        if zipfile.is_zipfile(packagePath):
-            with zipfile.ZipFile(packagePath, 'r') as archive:
-                version = archive.read(versionFile).decode('utf-8').strip()
+        here = path.abspath(path.dirname(__file__))
+        if '.zip' in here:
+            with zipfile.ZipFile(here[:-len("ai/h2o/sparkling/")], 'r') as archive:
+                version = archive.read('ai/h2o/sparkling/version.txt').decode('utf-8').strip()
         else:
-            with open(path.join(packagePath, versionFile), encoding='utf-8') as f:
+            with open(path.join(here, 'version.txt'), encoding='utf-8') as f:
                 version = f.read().strip()
 
         pySparklingVersionComponents = VersionComponents.parseFromSparklingWaterVersion(version)
@@ -216,18 +179,9 @@ class Initializer(object):
         sparkVersionFromPySparkling = pySparklingVersionComponents.sparkMajorMinorVersion
         sparkVersionFromPySpark = pySparkVersionComponents.sparkMajorMinorVersion
 
-        if not Initializer.isRunningViaDBCConnect() and not (sparkVersionFromPySpark == sparkVersionFromPySparkling):
+        if not (sparkVersionFromPySpark == sparkVersionFromPySparkling):
             raise Exception("""
             You are using PySparkling for Spark {}, but your PySpark is of version {}.
             Please make sure Spark and PySparkling versions are compatible.""".format(
                 sparkVersionFromPySparkling, sparkVersionFromPySpark))
-
-        if sparkVersionFromPySpark == "2.1":
-            warnings.warn(
-                "PySpark {} is unsupported since the Sparkling Water version 3.34.0.1-1.".format(pyspark.__version__))
-
-        if sparkVersionFromPySpark == "2.2":
-            warnings.warn("PySpark {} is deprecated and ".format(pyspark.__version__) +
-                          "the support will be removed in the Sparkling Water version 3.38.")
-
         return version
